/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc;

import junit.framework.TestCase;
import org.wso2.registry.*;
import org.wso2.registry.jdbc.realm.RegistryRealm;
import org.wso2.registry.jdbc.realm.InMemoryRegistryRealm;

public class DependencyTest extends TestCase {

    protected static Registry registry = null;
    protected static RegistryRealm realm = null;

    public void setUp() {
        try {
            if (registry == null) {
                realm = new InMemoryRegistryRealm();
                registry = new InMemoryJDBCRegistry(realm);
            }
        } catch (RegistryException e) {
            fail("Failed to initialize the registry. Caused by: " + e.getMessage());
        }
    }

    public void testSettingDependenciesInResources() throws RegistryException {

        Resource r1 = registry.newResource();
        r1.setContent("some content for first r1".getBytes());
        registry.put("/depTest/test1/r1", r1);

        Resource r2 = registry.newResource();
        r2.setContent("this is dependent on r1".getBytes());
        registry.put("/depTest/test1/r2", r2);
        registry.addAssociation(Association.DEPENDENCY, r2.getPath() ,"/depTest/test1/r1" );
        registry.addAssociation(Association.DEPENDENCY, r1.getPath() ,"/depTest/test1/r2");


        Resource r21 = registry.get("/depTest/test1/r1");
        Resource r22 = registry.get("/depTest/test1/r2");
        Association association [] = registry.getAllAssociations(r21.getPath()) ;
        assertNotNull(association);
        boolean found = false;
        for (int i = 0; i < association.length; i++) {
            Association association1 = association[i];
            if ("/depTest/test1/r2".equals(association1.getDestinationPath())){
                 found = true;
            }
        }
        assertTrue(found);
        association = registry.getAllAssociations(r22.getPath()) ;
        assertNotNull(association);
        found = false;
        for (int i = 0; i < association.length; i++) {
            Association association1 = association[i];
            if ("/depTest/test1/r1".equals(association1.getDestinationPath())){
                 found = true;
            }
        }
        assertTrue(found);
    }

    public void testSettingDependenciesFromAPI() throws RegistryException {

        Resource r1 = registry.newResource();
        r1.setContent("some content for second r1".getBytes());
        registry.put("/depTest/test2/r1", r1);

        Resource r2 = registry.newResource();
        r2.setContent("this is dependent on r2".getBytes());
        registry.put("/depTest/test2/r2", r2);

        registry.addAssociation(Association.DEPENDENCY, "/depTest/test2/r2", "/depTest/test2/r1");
        registry.addAssociation(Association.DEPENDENCY, "/depTest/test2/r1" ,"/depTest/test2/r2");

        Resource r21 = registry.get("/depTest/test2/r1");
        Resource r22 = registry.get("/depTest/test2/r2");
        Association association [] = registry.getAllAssociations(r21.getPath()) ;
        assertNotNull(association);
        boolean found = false;
        for (int i = 0; i < association.length; i++) {
            Association association1 = association[i];
            if ("/depTest/test2/r2".equals(association1.getDestinationPath())){
                 found = true;
            }
        }
        assertTrue(found);
        association = registry.getAllAssociations(r22.getPath()) ;
        assertNotNull(association);
        found = false;
        for (int i = 0; i < association.length; i++) {
            Association association1 = association[i];
            if ("/depTest/test2/r1".equals(association1.getDestinationPath())){
                 found = true;
            }
        }
        assertTrue(found);
    }



}
